from EEETools.Tools.main_tools import calculate, launch_connection_debug
from EEETools.Tools.main_tools import paste_default_excel_file, paste_components_documentation, paste_user_manual
